Helper function that sets Rstudio addin keyboard shortcuts
set_shortcut(fn, shortcut, overide = FALSE, verbose = TRUE)character, vector of package::function names
character, vector the same length of fn with corresponding shortcuts
boolean, set to TRUE to ignore any existing shortcut, Default: FALSE
boolean, set to TRUE to return a message on actions taken, Default: TRUE